@@ -1,24 +1,12 @@
 /*
- *  Copyright (C) 2015 Martin Blumenstingl <martin.blumenstingl@googlemail.com>
- *
- *  This library is free software; you can redistribute it and/or
- *  modify it under the terms of the GNU Library General Public
- *  License version 2 as published by the Free Software Foundation;
- *
- *  This library is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- *  Library General Public License for more details.
- *
- *  You should have received a copy of the GNU Library General Public License
- *  along with this library; see the file COPYING.LIB.  If not, write to
- *  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- *  Boston, MA 02110-1301, USA.
- */
+    SPDX-FileCopyrightText: 2015 Martin Blumenstingl <martin.blumenstingl@googlemail.com>
+
+    SPDX-License-Identifier: LGPL-2.0-only
+*/
 
 #include "deletejobtest.h"
 
-#include <QtTest/QtTest>
+#include <QtTest>
 #include <QDir>
 #include <QFile>
 #include <QTemporaryDir>
@@ -62,7 +50,7 @@ void DeleteJobTest::deleteFileTestCase()
         KIO::DeleteJob *job = KIO::del(QUrl::fromLocalFile(path), KIO::HideProgressInfo);
         job->setUiDelegate(nullptr);
 
-        QSignalSpy spy(job, SIGNAL(result(KJob*)));
+        QSignalSpy spy(job, &KJob::result);
         QVERIFY(spy.isValid());
         QVERIFY(spy.wait(100000));
         QCOMPARE(job->error(), KJOB_NO_ERROR);
@@ -92,7 +80,7 @@ void DeleteJobTest::deleteDirectoryTestCase()
         KIO::DeleteJob *job = KIO::del(QUrl::fromLocalFile(tempDir.path()), KIO::HideProgressInfo);
         job->setUiDelegate(nullptr);
 
-        QSignalSpy spy(job, SIGNAL(result(KJob*)));
+        QSignalSpy spy(job, &KJob::result);
         QVERIFY(spy.isValid());
         QVERIFY(spy.wait(100000));
         QCOMPARE(job->error(), KJOB_NO_ERROR);
