@@ -1,25 +1,13 @@
-/* This file is part of KDE
-    Copyright (c) 2006, 2008 David Faure <faure@kde.org>
+/*
+    This file is part of KDE
+    SPDX-FileCopyrightText: 2006, 2008 David Faure <faure@kde.org>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "fileundomanagertest.h"
 
-#include <qtest.h>
+#include <QTest>
 #include <QSignalSpy>
 #include <QDateTime>
 #include <QDir>
@@ -37,11 +25,11 @@
 #include <kio/batchrenamejob.h>
 #include <kioglobal_p.h>
 #include <kprotocolinfo.h>
-#include <kurlmimedata.h>
+#include <KUrlMimeData>
 
 #include <QDebug>
-#include <kconfig.h>
-#include <kconfiggroup.h>
+#include <KConfig>
+#include <KConfigGroup>
 
 #include <errno.h>
 #include <time.h>
@@ -253,8 +241,8 @@ void FileUndoManagerTest::cleanupTestCase()
 void FileUndoManagerTest::doUndo()
 {
     QEventLoop eventLoop;
-    bool ok = connect(FileUndoManager::self(), SIGNAL(undoJobFinished()),
-                      &eventLoop, SLOT(quit()));
+    bool ok = connect(FileUndoManager::self(), &FileUndoManager::undoJobFinished,
+                      &eventLoop, &QEventLoop::quit);
     QVERIFY(ok);
 
     FileUndoManager::self()->undo();
@@ -274,7 +262,7 @@ void FileUndoManagerTest::testCopyFiles()
 
     QSignalSpy spyUndoAvailable(FileUndoManager::self(), SIGNAL(undoAvailable(bool)));
     QVERIFY(spyUndoAvailable.isValid());
-    QSignalSpy spyTextChanged(FileUndoManager::self(), SIGNAL(undoTextChanged(QString)));
+    QSignalSpy spyTextChanged(FileUndoManager::self(), &FileUndoManager::undoTextChanged);
     QVERIFY(spyTextChanged.isValid());
 
     bool ok = job->exec();
@@ -589,7 +577,7 @@ void FileUndoManagerTest::testRestoreTrashedFiles()
 
     const QMap<QString, QString> metaData = job->metaData();
     QList<QUrl> trashUrls;
-    foreach (const QUrl &src, lst) {
+    for (const QUrl &src : qAsConst(lst)) {
         QMap<QString, QString>::ConstIterator it = metaData.find("trashURL-" + src.path());
         QVERIFY(it != metaData.constEnd());
         trashUrls.append(QUrl(it.value()));
@@ -631,9 +619,9 @@ void FileUndoManagerTest::testModifyFileBeforeUndo()
 {
     // based on testCopyDirectory (so that we check that it works for files in subdirs too)
     const QString destdir = destDir();
-    QList<QUrl> lst; lst << QUrl::fromLocalFile(srcSubDir());
-    const QUrl d = QUrl::fromLocalFile(destdir);
-    KIO::CopyJob *job = KIO::copy(lst, d, KIO::HideProgressInfo);
+    const QList<QUrl> lst{ QUrl::fromLocalFile(srcSubDir()) };
+    const QUrl dest = QUrl::fromLocalFile(destdir);
+    KIO::CopyJob *job = KIO::copy(lst, dest, KIO::HideProgressInfo);
     job->setUiDelegate(nullptr);
     FileUndoManager::self()->recordCopyJob(job);
 
@@ -642,7 +630,7 @@ void FileUndoManagerTest::testModifyFileBeforeUndo()
 
     checkTestDirectory(srcSubDir());   // src untouched
     checkTestDirectory(destSubDir());
-    const QString destFile =  destSubDir() + "/fileindir";
+    const QString destFile = destSubDir() + "/fileindir";
     setTimeStamp(destFile);   // simulate a modification of the file
 
     doUndo();
@@ -671,7 +659,7 @@ void FileUndoManagerTest::testPasteClipboardUndo()
 
     // Check if the clipboard was updated after paste operation
     QList<QUrl> urls2;
-    Q_FOREACH (const QUrl &url, urls) {
+    for (const QUrl &url : urls) {
         QUrl dUrl = destDirUrl.adjusted(QUrl::StripTrailingSlash);
         dUrl.setPath(dUrl.path() + '/' + url.fileName());
         urls2 << dUrl;
