@@ -1,29 +1,17 @@
 /*
- *  Copyright (C) 2004 David Faure <faure@kde.org>
- *
- *  This library is free software; you can redistribute it and/or
- *  modify it under the terms of the GNU Library General Public
- *  License version 2 as published by the Free Software Foundation;
- *
- *  This library is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- *  Library General Public License for more details.
- *
- *  You should have received a copy of the GNU Library General Public License
- *  along with this library; see the file COPYING.LIB.  If not, write to
- *  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- *  Boston, MA 02110-1301, USA.
- */
+    SPDX-FileCopyrightText: 2004 David Faure <faure@kde.org>
+
+    SPDX-License-Identifier: LGPL-2.0-only
+*/
 
 #include <QtTest>
-#include <qapplication.h>
+#include <QApplication>
 #include <kurlcompletion.h>
 #include <KUser>
 #include <QDebug>
 #include <QDir>
 #include <QFile>
-#include <qtemporarydir.h>
+#include <QTemporaryDir>
 #include <QThread>
 #include <qplatformdefs.h>
 
