@@ -1,29 +1,17 @@
-/* This file is part of the KDE project
-   Copyright (C) 1998, 1999 Torben Weis <weis@kde.org>
-                 2000 Carsten Pfeiffer <pfeiffer@kde.org>
-                 2003-2005 David Faure <faure@kde.org>
-                 2001-2006 Michael Brade <brade@kde.org>
+/*
+    This file is part of the KDE project
+    SPDX-FileCopyrightText: 1998, 1999 Torben Weis <weis@kde.org>
+    SPDX-FileCopyrightText: 2000 Carsten Pfeiffer <pfeiffer@kde.org>
+    SPDX-FileCopyrightText: 2003-2005 David Faure <faure@kde.org>
+    SPDX-FileCopyrightText: 2001-2006 Michael Brade <brade@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "kcoredirlister.h"
 #include "kcoredirlister_p.h"
 
-#include <klocalizedstring.h>
+#include <KLocalizedString>
 #include <kio/listjob.h>
 #include "kprotocolmanager.h"
 #include "kmountpoint.h"
@@ -35,13 +23,13 @@
 #include <QFile>
 #include <QTextStream>
 #include <QDir>
-#include <qmimedatabase.h>
+#include <QMimeDatabase>
 
 #include <list>
 
 #include <QLoggingCategory>
 Q_DECLARE_LOGGING_CATEGORY(KIO_CORE_DIRLISTER)
-Q_LOGGING_CATEGORY(KIO_CORE_DIRLISTER, "kf5.kio.core.dirlister", QtWarningMsg)
+Q_LOGGING_CATEGORY(KIO_CORE_DIRLISTER, "kf.kio.core.dirlister", QtWarningMsg)
 
 // Enable this to get printDebug() called often, to see the contents of the cache
 //#define DEBUG_CACHE
@@ -102,16 +90,6 @@ bool KCoreDirListerCache::listDir(KCoreDirLister *lister, const QUrl &_u,
     QUrl _url(_u);
     _url.setPath(QDir::cleanPath(_url.path())); // kill consecutive slashes
 
-    if (!_url.host().isEmpty() && KProtocolInfo::protocolClass(_url.scheme()) == QLatin1String(":local")
-            && _url.scheme() != QLatin1String("file")) {
-        // ":local" protocols ignore the hostname, so strip it out preventively - #160057
-        // kio_file is special cased since it does honor the hostname (by redirecting to e.g. smb)
-        _url.setHost(QString());
-        if (_keep == false) {
-            emit lister->redirection(_url);
-        }
-    }
-
     // like this we don't have to worry about trailing slashes any further
     _url = _url.adjusted(QUrl::StripTrailingSlash);
 
