@@ -1,21 +1,9 @@
-/* This file is part of the KDE libraries
-    Copyright (C) 2000 Stephan Kulow <coolo@kde.org>
-                  2000-2009 David Faure <faure@kde.org>
+/*
+    This file is part of the KDE libraries
+    SPDX-FileCopyrightText: 2000 Stephan Kulow <coolo@kde.org>
+    SPDX-FileCopyrightText: 2000-2009 David Faure <faure@kde.org>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef KIO_LISTJOB_H
@@ -42,7 +30,7 @@ class KIOCORE_EXPORT ListJob : public SimpleJob
     Q_OBJECT
 
 public:
-    ~ListJob();
+    ~ListJob() override;
 
     /**
      * Returns the ListJob's redirection URL. This will be invalid if there
@@ -97,13 +85,14 @@ Q_SIGNALS:
     void permanentRedirection(KIO::Job *job, const QUrl &fromUrl, const QUrl &toUrl);
 
 protected Q_SLOTS:
-    void slotFinished() Q_DECL_OVERRIDE;
-    void slotMetaData(const KIO::MetaData &_metaData) Q_DECL_OVERRIDE;
-    void slotResult(KJob *job) Q_DECL_OVERRIDE;
+    void slotFinished() override;
+    void slotMetaData(const KIO::MetaData &_metaData) override;
+    void slotResult(KJob *job) override;
 
 protected:
     ListJob(ListJobPrivate &dd);
     Q_DECLARE_PRIVATE(ListJob)
+    friend class ListJobPrivate;
 };
 
 /**
