@@ -1,32 +1,20 @@
 /*
-   This file is part of the KDE libraries
-   Copyright (c) 2002 Waldo Bastian <bastian@kde.org>
-   Copyright 2009 David Faure <faure@kde.org>
+    This file is part of the KDE libraries
+    SPDX-FileCopyrightText: 2002 Waldo Bastian <bastian@kde.org>
+    SPDX-FileCopyrightText: 2009 David Faure <faure@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License version 2 as published by the Free Software Foundation.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-only
 */
 
 #include "httpfilter.h"
-#include <kcompressiondevice.h>
-#include <kfilterbase.h>
+#include <KCompressionDevice>
+#include <KFilterBase>
 #include <KLocalizedString>
 #include <QDebug>
 
 #include <stdio.h>
 
-Q_LOGGING_CATEGORY(KIO_HTTP_FILTER, "kf5.kio.kio_http.filter")
+Q_LOGGING_CATEGORY(KIO_HTTP_FILTER, "kf.kio.slaves.http.filter")
 
 /*
 Testcases:
