@@ -1,27 +1,10 @@
 /*
-This file is part of KDE
+    This file is part of KDE
+    SPDX-FileCopyrightText: 1998-2000 Waldo Bastian <bastian@kde.org>
 
-  Copyright (C) 1998-2000 Waldo Bastian (bastian@kde.org)
+    SPDX-License-Identifier: MIT
+*/
 
-Permission is hereby granted, free of charge, to any person obtaining a copy
-of this software and associated documentation files (the "Software"), to deal
-in the Software without restriction, including without limitation the rights
-to use, copy, modify, merge, publish, distribute, and/or sell
-copies of the Software, and to permit persons to whom the Software is
-furnished to do so, subject to the following conditions:
-
-The above copyright notice and this permission notice shall be included in
-all copies or substantial portions of the Software.
-
-THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
-IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
-FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL THE
-AUTHORS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN
-AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
-CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
- */
-//----------------------------------------------------------------------------
-//
 // KDE Cookie Server
 
 #include "kcookieserver.h"
@@ -32,14 +15,14 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #include <QFile>
 #include <QDBusConnection>
 
-#include <kconfig.h>
+#include <KConfig>
 #include <QDebug>
 
-#include <kpluginfactory.h>
-#include <kpluginloader.h>
+#include <KPluginFactory>
+#include <KPluginLoader>
 #include <KLocalizedString>
 #include <kwindowsystem.h>
-#include <qstandardpaths.h>
+#include <QStandardPaths>
 #include <QMessageBox>
 
 #include <QLoggingCategory>
@@ -49,9 +32,7 @@ Q_DECLARE_LOGGING_CATEGORY(KIO_COOKIEJAR)
 #include "kcookiewin.h"
 #include "kcookieserveradaptor.h"
 
-K_PLUGIN_FACTORY_WITH_JSON(KdedCookieServerFactory,
-                           "kcookiejar.json",
-                           registerPlugin<KCookieServer>();)
+K_PLUGIN_CLASS_WITH_JSON(KCookieServer, "kcookiejar.json")
 
 static QDir getOrCreateCookieJarDir()
 {
@@ -144,7 +125,7 @@ bool KCookieServer::cookiesPending(const QString &url, KHttpCookieList *cookieLi
 
     QStringList domains;
     mCookieJar->extractDomains(fqdn, domains);
-    Q_FOREACH (const KHttpCookie &cookie, *mPendingCookies) {
+    for (const KHttpCookie &cookie : qAsConst(*mPendingCookies)) {
         if (cookie.match(fqdn, domains, path)) {
             if (!cookieList) {
                 return true;
@@ -238,7 +219,8 @@ void KCookieServer::checkCookies(KHttpCookieList *cookieList, qlonglong windowId
                                     mCookieJar->preferredDefaultPolicy(),
                                     mCookieJar->showCookieDetails());
     if (windowId > 0) {
-        KWindowSystem::setMainWindow(kw, windowId);
+        kw->setAttribute(Qt::WA_NativeWindow, true);
+        KWindowSystem::setMainWindow(kw->windowHandle(), windowId);
     }
 
     KCookieAdvice userAdvice = kw->advice(mCookieJar, currentCookie);
@@ -318,7 +300,7 @@ void KCookieServer::saveCookieJar()
 void KCookieServer::putCookie(QStringList &out, const KHttpCookie &cookie,
                               const QList<int> &fields)
 {
-    foreach (int i, fields) {
+    for (int i : fields) {
         switch (i) {
         case CF_DOMAIN :
             out << cookie.domain();
@@ -390,7 +372,7 @@ QStringList
 KCookieServer::findDomains()
 {
     QStringList result;
-    Q_FOREACH (const QString &domain, mCookieJar->getDomainList()) {
+    for (const QString &domain : mCookieJar->getDomainList()) {
         // Ignore domains that have policy set for but contain
         // no cookies whatsoever...
         const KHttpCookieList *list =  mCookieJar->getCookieList(domain, QString());
@@ -414,12 +396,12 @@ KCookieServer::findCookies(const QList<int> &fields,
     const QStringList domainList = _domain.split(QLatin1Char(' '));
 
     if (allCookies) {
-        Q_FOREACH (const QString &domain, domainList) {
+        for (const QString &domain : domainList) {
             const KHttpCookieList *list =  mCookieJar->getCookieList(domain, fqdn);
             if (!list) {
                 continue;
             }
-            Q_FOREACH (const KHttpCookie &cookie, *list) {
+            for (const KHttpCookie &cookie : *list) {
                 if (cookie.isExpired()) {
                     continue;
                 }
@@ -427,12 +409,12 @@ KCookieServer::findCookies(const QList<int> &fields,
             }
         }
     } else {
-        Q_FOREACH (const QString &domain, domainList) {
+        for (const QString &domain : domainList) {
             const KHttpCookieList *list =  mCookieJar->getCookieList(domain, fqdn);
             if (!list) {
                 continue;
             }
-            Q_FOREACH (const KHttpCookie &cookie, *list) {
+            for (const KHttpCookie &cookie : *list) {
                 if (cookie.isExpired()) {
                     continue;
                 }
