@@ -1,28 +1,16 @@
 /**
- * kcookiespolicies.cpp - Cookies configuration
- *
- * Original Authors
- * Copyright (c) Waldo Bastian <bastian@kde.org>
- * Copyright (c) 1999 David Faure <faure@kde.org>
- * Copyright (c) 2008 Urs Wolfer <uwolfer @ kde.org>
- *
- * Re-written by:
- * Copyright (c) 2000- Dawit Alemayehu <adawit@kde.org>
- *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
- */
+    kcookiespolicies.cpp - Cookies configuration
+
+    Original Authors
+    SPDX-FileCopyrightText: Waldo Bastian <bastian@kde.org>
+    SPDX-FileCopyrightText: 1999 David Faure <faure@kde.org>
+    SPDX-FileCopyrightText: 2008 Urs Wolfer <uwolfer @ kde.org>
+
+    Re-written by:
+    SPDX-FileCopyrightText: 2000 Dawit Alemayehu <adawit@kde.org>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 // Own
 #include "kcookiespolicies.h"
@@ -37,11 +25,11 @@
 #include <QDBusInterface>
 
 // KDE
-#include <kiconloader.h>
-#include <kmessagebox.h>
+#include <KIconLoader>
+#include <KMessageBox>
 #include <KConfigGroup>
 #include <KLocalizedString>
-#include <kconfig.h>
+#include <KConfig>
 #include <QUrl>
 
 
