@@ -1,23 +1,11 @@
-/* This file is part of the KDE project
-   Copyright (C) 1998, 1999 Torben Weis <weis@kde.org>
-   Copyright (c) 1999, 2000 Preston Brown <pbrown@kde.org>
-   Copyright (c) 2000 Simon Hausmann <hausmann@kde.org>
-   Copyright (c) 2000 David Faure <faure@kde.org>
+/*
+    This file is part of the KDE project
+    SPDX-FileCopyrightText: 1998, 1999 Torben Weis <weis@kde.org>
+    SPDX-FileCopyrightText: 1999, 2000 Preston Brown <pbrown@kde.org>
+    SPDX-FileCopyrightText: 2000 Simon Hausmann <hausmann@kde.org>
+    SPDX-FileCopyrightText: 2000 David Faure <faure@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef KPROPERTIESDIALOG_H
@@ -28,7 +16,7 @@
 
 #include "kiowidgets_export.h"
 #include <kfileitem.h>
-#include <kpagedialog.h>
+#include <KPageDialog>
 
 class KPropertiesDialogPlugin;
 
@@ -234,11 +222,12 @@ public:
      */
     void insertPlugin(KPropertiesDialogPlugin *plugin);
 
-#ifndef KIOWIDGETS_NO_DEPRECATED
+#if KIOWIDGETS_ENABLE_DEPRECATED_SINCE(5, 0)
     /**
      * @deprecated since 5.0, use url()
      */
-    KIOWIDGETS_DEPRECATED QUrl kurl() const
+    KIOWIDGETS_DEPRECATED_VERSION(5, 0, "Use KPropertiesDialog::url()")
+    QUrl kurl() const
     {
         return url();
     }
@@ -318,6 +307,8 @@ public:
      * This page is shown when calling showFileSharingPage().
      *
      * @param page the page to set
+     *
+     * \note This should only be called by KPropertiesDialog plugins.
      * \see showFileSharingPage
      */
     void setFileSharingPage(QWidget *page);
@@ -336,23 +327,25 @@ public Q_SLOTS:
      * Called when the user presses 'Ok'.
      * @deprecated since 5.25, use accept()
      */
-    KIOWIDGETS_DEPRECATED virtual void slotOk();
+    KIOWIDGETS_DEPRECATED_VERSION(5, 25, "Use KPropertiesDialog::accept()")
+    virtual void slotOk();
     /**
      * Called when the user presses 'Cancel'.
      * @deprecated since 5.25, use reject()
      */
-    KIOWIDGETS_DEPRECATED virtual void slotCancel();
+    KIOWIDGETS_DEPRECATED_VERSION(5, 25, "Use KPropertiesDialog::reject()")
+    virtual void slotCancel();
 
     /**
      * Called when the user presses 'Ok'.
      * @since 5.25
      */
-    void accept() Q_DECL_OVERRIDE;
+    void accept() override;
     /**
      * Called when the user presses 'Cancel' or Esc.
      * @since 5.25
      */
-    void reject() Q_DECL_OVERRIDE;
+    void reject() override;
 
 Q_SIGNALS:
     /**
@@ -422,13 +415,14 @@ public:
      */
     virtual void applyChanges();
 
+#if KIOWIDGETS_ENABLE_DEPRECATED_SINCE(4, 1)
     /**
      * Convenience method for most ::supports methods
      * @return true if the file is a local, regular, readable, desktop file
-     * @deprecated use KFileItem::isDesktopFile
+     * @deprecated Since 4.1, use KFileItem::isDesktopFile
      */
-#ifndef KIOWIDGETS_NO_DEPRECATED
-    static KIOWIDGETS_DEPRECATED bool isDesktopFile(const KFileItem &_item);
+    KIOWIDGETS_DEPRECATED_VERSION(4, 1, "Use KFileItem::isDesktopFile()")
+    static bool isDesktopFile(const KFileItem &_item);
 #endif
 
     void setDirty(bool b);
