@@ -1,23 +1,11 @@
 // -*- c++ -*-
-/*  This file is part of the KDE libraries
-    Copyright (C) 2000 David Faure <faure@kde.org>
-                  2000 Carsten Pfeiffer <pfeiffer@kde.org>
-                  2001 Malte Starostik <malte.starostik@t-online.de>
+/*
+    This file is part of the KDE libraries
+    SPDX-FileCopyrightText: 2000 David Faure <faure@kde.org>
+    SPDX-FileCopyrightText: 2000 Carsten Pfeiffer <pfeiffer@kde.org>
+    SPDX-FileCopyrightText: 2001 Malte Starostik <malte.starostik@t-online.de>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "previewjob.h"
@@ -41,19 +29,19 @@
 #include <QPixmap>
 #include <QTimer>
 #include <QRegularExpression>
-#include <qtemporaryfile.h>
-#include <qsavefile.h>
+#include <QTemporaryFile>
+#include <QSaveFile>
 
 #include <QCryptographicHash>
 
 #include <kfileitem.h>
-#include <kservicetypetrader.h>
-#include <kservice.h>
-#include <ksharedconfig.h>
-#include <kconfiggroup.h>
+#include <KServiceTypeTrader>
+#include <KService>
+#include <KSharedConfig>
+#include <KConfigGroup>
 #include <kprotocolinfo.h>
-#include <qmimedatabase.h>
-#include <qstandardpaths.h>
+#include <QMimeDatabase>
+#include <QStandardPaths>
 #include <KMountPoint>
 
 #include <algorithm>
@@ -551,14 +539,13 @@ bool PreviewJobPrivate::statResultThumbnail()
         return false;
     }
 
-    QUrl url = currentItem.item.mostLocalUrl();
+    const QUrl url = currentItem.item.mostLocalUrl();
     // Don't include the password if any
-    url.setPassword(QString());
-    origName = url.toEncoded();
+    origName = url.toEncoded(QUrl::RemovePassword);
 
     QCryptographicHash md5(QCryptographicHash::Md5);
-    md5.addData(QFile::encodeName(QString::fromUtf8(origName)));
-    thumbName = QString::fromUtf8(QFile::encodeName(QString::fromLatin1(md5.result().toHex()))) + QLatin1String(".png");
+    md5.addData(origName);
+    thumbName = QString::fromLatin1(md5.result().toHex()) + QLatin1String(".png");
 
     QImage thumb;
     if (!thumb.load(thumbPath + thumbName)) {
